summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/timeedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/timeedit.h')
-rw-r--r--kalarm/lib/timeedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalarm/lib/timeedit.h b/kalarm/lib/timeedit.h
index 7be73c1f..658fe780 100644
--- a/kalarm/lib/timeedit.h
+++ b/kalarm/lib/timeedit.h
@@ -53,10 +53,10 @@ class TimeEdit : public TQHBox
TQ_OBJECT
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit TimeEdit(TQWidget* tqparent = 0, const char* name = 0);
+ explicit TimeEdit(TQWidget* parent = 0, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the widget is read-only for the user. If read-only,
@@ -53,10 +53,10 @@ class TimeEdit : public TQHBox
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/